@@ -22,7 +22,7 @@ moveValuesToRowsN <- function(wideTable,
                               my_db,
                               ...,
                               columnsToCopy = NULL,
-                              tempNameGenerator = makeTempNameGenerator('mvtrq'),
+                              tempNameGenerator = wrapr::mk_tmp_name_source('mvtrq'),
                               strict = FALSE,
                               checkNames = TRUE,
                               showQuery = FALSE,
@@ -121,7 +121,7 @@ moveValuesToColumnsN <- function(tallTable,
                                  my_db,
                                  ...,
                                  columnsToCopy = NULL,
-                                 tempNameGenerator = makeTempNameGenerator('mvtcq'),
+                                 tempNameGenerator = wrapr::mk_tmp_name_source('mvtcq'),
                                  strict = FALSE,
                                  checkNames = TRUE,
                                  showQuery = FALSE,
