@@ -1,9 +1,14 @@
 ## ----ex1-----------------------------------------------------------------
 library("cdata")
-my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+my_db <- DBI::dbConnect(RSQLite::SQLite(), 
+                        ":memory:")
 
 # pivot example
-d <- data.frame(meas = c('AUC', 'R2'), val = c(0.6, 0.2))
+d <- build_frame(
+   "meas", "val" /
+   "AUC" , 0.6   /
+   "R2"  , 0.2   )
+
 DBI::dbWriteTable(my_db,
                   'd',
                   d,
@@ -11,13 +16,13 @@ DBI::dbWriteTable(my_db,
 qlook(my_db, 'd')
 
 cT <- build_pivot_control_q('d',
-                              columnToTakeKeysFrom= 'meas',
-                              columnToTakeValuesFrom= 'val',
-                              my_db = my_db)
-tab <- blocks_to_rowrecs_q('d',
-                            keyColumns = NULL,
-                            controlTable = cT,
+                            columnToTakeKeysFrom= 'meas',
+                            columnToTakeValuesFrom= 'val',
                             my_db = my_db)
+tab <- blocks_to_rowrecs_q('d',
+                           keyColumns = NULL,
+                           controlTable = cT,
+                           my_db = my_db)
 qlook(my_db, tab)
 
 DBI::dbDisconnect(my_db)
